# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['bpytop']
install_requires = \
['psutil>=5.7.0,<6.0.0']

entry_points = \
{'console_scripts': ['bpytop = bpytop:main']}

setup_kwargs = {
    'name': 'bpytop',
    'version': '1.0.67',
    'description': 'Resource monitor that shows usage and stats for processor, memory, disks, network and processes.',
    'long_description': '# ![bpytop](https://github.com/aristocratos/bpytop/raw/master/Imgs/logo.png)\n\n<a href="https://repology.org/project/bpytop/versions">\n    <img src="https://repology.org/badge/vertical-allrepos/bpytop.svg" alt="Packaging status" align="right">\n</a>\n\n![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)\n![OSX](https://img.shields.io/badge/-OSX-black?logo=apple)\n![FreeBSD](https://img.shields.io/badge/-FreeBSD-red?logo=freebsd)\n![Usage](https://img.shields.io/badge/Usage-System%20resource%20monitor-yellow)\n![Python](https://img.shields.io/badge/Python-v3.7%5E-green?logo=python)\n![bpytop_version](https://img.shields.io/github/v/tag/aristocratos/bpytop?label=version)\n[![pypi_version](https://img.shields.io/pypi/v/bpytop?label=pypi)](https://pypi.org/project/bpytop)\n[![Test Status](https://img.shields.io/github/workflow/status/aristocratos/bpytop/Testing?label=tests)](https://github.com/aristocratos/bpytop/actions?query=workflow%3Atesting)\n[![Donate](https://img.shields.io/badge/-Donate-yellow?logo=paypal)](https://paypal.me/aristocratos)\n[![Sponsor](https://img.shields.io/badge/-Sponsor-red?logo=github)](https://github.com/sponsors/aristocratos)\n[![Coffee](https://img.shields.io/badge/-Buy%20me%20a%20Coffee-grey?logo=Ko-fi)](https://ko-fi.com/aristocratos)\n\n[![bpytop](https://img.shields.io/badge/-snapcraft.io-black)](https://snapcraft.io/bpytop)[![bpytop](https://snapcraft.io//bpytop/badge.svg)](https://snapcraft.io/bpytop)\n\n## Index\n\n* [News](#news)\n* [Documents](#documents)\n* [Description](#description)\n* [Features](#features)\n* [Themes](#themes)\n* [Support and funding](#support-and-funding)\n* [Prerequisites](#prerequisites) (Read this if you are having issues!)\n* [Dependencies](#dependencies)\n* [Screenshots](#screenshots)\n* [Installation](#installation)\n* [Configurability](#configurability)\n* [License](#license)\n\n## News\n\n### C++ Version\n##### 2 May 2021\n\nI\'ve started work on the third iteration of bashtop->bpytop.\nIt\'s being written in C++ and will simply be called `btop`.\n\nI\'m aiming at releasing a beta version around August this year and will publish the repo when I\'ve got the core functionality and structure ready for anybody that wanna help out.\n\nThis project is gonna take some time until it has complete feature parity with bpytop, since all system information gathering will likely have to be written from scratch without any external libraries.\nAnd will need some help in the form of code contributions to get complete support for BSD and OSX.\n\nIf you got suggestions of C++ libraries that are multi-platform and are as extensive as [psutil](https://github.com/giampaolo/psutil) are for python, feel free to open up a new thread in Discussions, it could help speed up the development a lot.\n\nWill post any updates about this project here until the repo is made available.\n\n## Documents\n\n#### [CHANGELOG.md](https://github.com/aristocratos/bpytop/blob/master/CHANGELOG.md)\n\n#### [CONTRIBUTING.md](https://github.com/aristocratos/bpytop/blob/master/CONTRIBUTING.md)\n\n#### [CODE_OF_CONDUCT.md](https://github.com/aristocratos/bpytop/blob/master/CODE_OF_CONDUCT.md)\n\n## Description\n\nResource monitor that shows usage and stats for processor, memory, disks, network and processes.\n\nPython port and continuation of [bashtop](https://github.com/aristocratos/bashtop).\n\n## Features\n\n* Easy to use, with a game inspired menu system.\n* Full mouse support, all buttons with a highlighted key is clickable and mouse scroll works in process list and menu boxes.\n* Fast and responsive UI with UP, DOWN keys process selection.\n* Function for showing detailed stats for selected process.\n* Ability to filter processes, multiple filters can be entered.\n* Easy switching between sorting options.\n* Send SIGTERM, SIGKILL, SIGINT to selected process.\n* UI menu for changing all config file options.\n* Auto scaling graph for network usage.\n* Shows message in menu if new version is available\n* Shows current read and write speeds for disks\n\n## Themes\n\nBpytop uses the same theme files as bashtop so any theme made for bashtop will work.\n\nSee [themes](https://github.com/aristocratos/bpytop/tree/master/themes) folder for available themes.\n\nThe `make install` command places the default themes in `/usr/local/share/bpytop/themes`.\nIf installed with `pip3` the themes will be located in a folder called `bpytop-themes` in the python3 site-packages folder.\nUser created themes should be placed in `$HOME/.config/bpytop/themes`.\n\nLet me know if you want to contribute with new themes.\n\n## Support and funding\n\nYou can sponsor this project through github, see [my sponsors page](https://github.com/sponsors/aristocratos) for options.\n\nOr donate through [paypal](https://paypal.me/aristocratos) or [ko-fi](https://ko-fi.com/aristocratos).\n\nAny support is greatly appreciated!\n\n## Prerequisites\n\n#### Mac Os X\n\nWill not display correctly in the standard terminal (unless truecolor is set to False)!\nRecommended alternative [iTerm2](https://www.iterm2.com/)\n\nWill also need to be run as superuser to display stats for processes not owned by user.\n\nOsX on Apple Silicon (arm) requires psutil version 5.8.0 to work and currently has no temperature monitoring.\nUpgrade psutil with `sudo pip3 install psutil --upgrade`\n\n#### Linux, Mac Os X and FreeBSD\n\nFor correct display, a terminal with support for:\n\n* 24-bit truecolor ([See list of terminals with truecolor support](https://gist.github.com/XVilka/8346728))\n* 256-color terminals are supported through 24-bit to 256-color conversion when setting "truecolor" to False in the options or with "-lc/--low-color" argument.\n* Wide characters (Are sometimes problematic in web-based terminals)\n\nAlso needs a UTF8 locale and a font that covers:\n\n* Unicode Block “Braille Patterns” U+2800 - U+28FF\n* Unicode Block “Geometric Shapes” U+25A0 - U+25FF\n* Unicode Block "Box Drawing" and "Block Elements" U+2500 - U+259F\n\n#### Notice (Text rendering issues)\n\nIf you are having problems with the characters in the graphs not looking like they do in the screenshots,\nit\'s likely a problem with your systems configured fallback font not having support for braille characters.\n\nSee [Terminess Powerline](https://github.com/ryanoasis/nerd-fonts/tree/master/patched-fonts/Terminus/terminus-ttf-4.40.1) for an example of a font that includes the braille symbols.\n\nSee comments by @sgleizes [link](https://github.com/aristocratos/bpytop/issues/100#issuecomment-684036827) and @XenHat [link](https://github.com/aristocratos/bpytop/issues/100#issuecomment-691585587) in issue #100 for possible solutions.\n\nIf text are misaligned and you are using Konsole or Yakuake, turning off "Bi-Directional text rendering" is a possible fix.\n\nCharacters clipping in to each other or text/border misalignments is not bugs caused by bpytop, but most likely a fontconfig or terminal problem where the braille characters making up the graphs aren\'t rendered correctly.\nLook to the creators of the terminal emulator you use to fix these issues if the previous mentioned fixes don\'t work for you.\n\n#### Notice (SSH)\n\nDropbear seems to not be able to set correct locale. So if accessing bpytop over ssh, OpenSSH is recommended.\n\n## Dependencies\n\n**[Python3](https://www.python.org/downloads/)** (v3.7 or later)\n\n**[psutil module](https://github.com/giampaolo/psutil)** (v5.7.0 or later)\n\n## Optionals for additional stats\n\n(Optional OSX) **[coretemp](https://github.com/hacker1024/coretemp)** (recommended), or **[osx-cpu-temp](https://github.com/lavoiesl/osx-cpu-temp)** (less accurate) needed to show CPU temperatures.\n\n## Screenshots\n\nMain UI showing details for a selected process.\n![Screenshot 1](https://github.com/aristocratos/bpytop/raw/master/Imgs/main.png)\n\nMain UI in mini mode.\n![Screenshot 2](https://github.com/aristocratos/bpytop/raw/master/Imgs/mini.png)\n\nMain menu.\n![Screenshot 3](https://github.com/aristocratos/bpytop/raw/master/Imgs/menu.png)\n\nOptions menu.\n![Screenshot 4](https://github.com/aristocratos/bpytop/raw/master/Imgs/options.png)\n\n## Installation\n\nI only maintain the PyPi package, so will not take responsibility for issues caused by any other install method!\n\n### PyPi (will always have latest version)\n\n> Install or update to latest version\n``` bash\npip3 install bpytop --upgrade\n```\n\n### Mac OsX\n\n>Install with Homebrew\n```bash\nbrew install bpytop\n```\n\n>Optional coretemp (Shows temperatures for cpu cores)\n```bash\nbrew install hacker1024/hacker1024/coretemp\n```\n\n>Alternatively install with MacPorts\n```bash\nport install bpytop\n```\n\nOsX on Apple Silicon (arm) requires psutil version 5.8.0 to work and currently has no temperature monitoring.\nUpgrade psutil with `sudo pip3 install psutil --upgrade`\n\n### Arch Linux\n\nAvailable in the Arch Linux [community] repository as `bpytop`\n\n>Installation\n\n```bash\nsudo pacman -S bpytop\n```\n\n### Debian based\n\nAvailable in [official Debian repository](https://tracker.debian.org/pkg/bpytop) since Debian 11\n\n>Installation\n\n```bash\nsudo apt install bpytop\n```\n\nAvailable for debian/ubuntu from [Azlux\'s repository](http://packages.azlux.fr/)\n\n### FreeBSD package\n\nAvailable in [FreeBSD ports](https://www.freshports.org/sysutils/bpytop/)\n\n>Install pre-built package\n\n``` bash\nsudo pkg install bpytop\n```\n\n### Fedora/CentOS 8 package\n\n[Available](https://src.fedoraproject.org/rpms/bpytop) in the Fedora and [EPEL-8 repository](https://fedoraproject.org/wiki/EPEL).\n\n>Installation\n\n``` bash\nsudo dnf install bpytop\n```\n\n### Gentoo / Calculate Linux\n\nAvailable from [adrien-overlay](https://github.com/aaaaadrien/adrien-overlay)\n\n>Installation\n\n``` bash\nsudo emerge -av sys-process/bpytop\n```\n\n### Mageia Cauldron (Mageia 8)\n\nAvailable in Mageia Cauldron and then Mageia 8 when it is released.\n\n>Installation\n\n``` bash\nsudo urpmi bpytop\nsudo dnf install bpytop\n```\n\n### MX Linux\n\nAvailable in the MX Test Repo as `bpytop`\nPlease use MX Package Installer MX Test Repo tab to install.\n\nhttp://mxrepo.com/mx/testrepo/pool/test/b/bpytop/\n\n### Void Linux\n\nAvailable in void repo and void-packages ports tree\n\n>Installation\n\n``` bash\nsudo xbps-install bpytop\n```\n\n### Snap package\n\n(Note! There is some issues caused by the snap sandboxing)\n\nby @kz6fittycent\n\nhttps://github.com/kz6fittycent/bpytop-snap\n\n>Install the package\n``` bash\nsudo snap install bpytop\n```\n\nThe config folder will be located in `~/snap/bpytop/current/.config/bpytop`\n\n## Manual installation\n\n#### Dependencies installation Linux\n\n>Install python3 and git with a package manager of you choice\n\n>Install psutil python module (sudo might be required)\n\n``` bash\npython3 -m pip install psutil\n```\n\n#### Dependencies installation OSX\n\n>Install homebrew if not already installed\n\n``` bash\n/bin/bash -c "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install.sh)"\n```\n\n>Install python3 if not already installed\n\n``` bash\nbrew install python3 git\n```\n\n>Install psutil python module\n\n``` bash\npython3 -m pip install psutil\n```\n\n>Install optional dependency coretemp (recommended), or osx-cpu-temp (less accurate)\n\n``` bash\nbrew install hacker1024/hacker1024/coretemp\n```\n\n``` bash\nbrew install osx-cpu-temp\n```\n\n#### Dependencies installation FreeBSD\n\n>Install with pkg and pip\n\n``` bash\nsudo pkg install git python3 py37-psutil\n```\n\n#### Manual installation Linux, OSX and FreeBSD\n\n>Clone and install\n\n``` bash\ngit clone https://github.com/aristocratos/bpytop.git\ncd bpytop\nsudo make install\n```\n\n>to uninstall it\n\n``` bash\nsudo make uninstall\n```\n\n## Configurability\n\nAll options changeable from within UI.\nConfig files stored in "$HOME/.config/bpytop" folder\n\n#### bpytop.cfg: (auto generated if not found)\n\n"/etc/bpytop.conf" will be used as default seed for config file creation if it exists. ("/usr/local/etc/bpytop.conf" on BSD)\n\n```bash\n#? Config file for bpytop v. 1.0.64\n\n#* Color theme, looks for a .theme file in "/usr/[local/]share/bpytop/themes" and "~/.config/bpytop/themes", "Default" for builtin default theme.\n#* Prefix name by a plus sign (+) for a theme located in user themes folder, i.e. color_theme="+monokai"\ncolor_theme="monokai"\n\n#* If the theme set background should be shown, set to False if you want terminal background transparency\ntheme_background=False\n\n#* Sets if 24-bit truecolor should be used, will convert 24-bit colors to 256 color (6x6x6 color cube) if false.\ntruecolor=True\n\n#* Manually set which boxes to show. Available values are "cpu mem net proc", separate values with whitespace.\nshown_boxes="cpu mem net proc"\n\n#* Update time in milliseconds, increases automatically if set below internal loops processing time, recommended 2000 ms or above for better sample times for graphs.\nupdate_ms=2000\n\n#* Processes update multiplier, sets how often the process list is updated as a multiplier of "update_ms".\n#* Set to 2 or higher to greatly decrease bpytop cpu usage. (Only integers)\nproc_update_mult=2\n\n#* Processes sorting, "pid" "program" "arguments" "threads" "user" "memory" "cpu lazy" "cpu responsive",\n#* "cpu lazy" updates top process over time, "cpu responsive" updates top process directly.\nproc_sorting="cpu lazy"\n\n#* Reverse sorting order, True or False.\nproc_reversed=False\n\n#* Show processes as a tree\nproc_tree=False\n\n#* Which depth the tree view should auto collapse processes at\ntree_depth=3\n\n#* Use the cpu graph colors in the process list.\nproc_colors=True\n\n#* Use a darkening gradient in the process list.\nproc_gradient=True\n\n#* If process cpu usage should be of the core it\'s running on or usage of the total available cpu power.\nproc_per_core=False\n\n#* Show process memory as bytes instead of percent\nproc_mem_bytes=True\n\n#* Sets the CPU stat shown in upper half of the CPU graph, "total" is always available, see:\n#* https://psutil.readthedocs.io/en/latest/#psutil.cpu_times for attributes available on specific platforms.\n#* Select from a list of detected attributes from the options menu\ncpu_graph_upper="total"\n\n#* Sets the CPU stat shown in lower half of the CPU graph, "total" is always available, see:\n#* https://psutil.readthedocs.io/en/latest/#psutil.cpu_times for attributes available on specific platforms.\n#* Select from a list of detected attributes from the options menu\ncpu_graph_lower="total"\n\n#* Toggles if the lower CPU graph should be inverted.\ncpu_invert_lower=True\n\n#* Set to True to completely disable the lower CPU graph.\ncpu_single_graph=False\n\n#* Shows the system uptime in the CPU box.\nshow_uptime=True\n\n#* Check cpu temperature, needs "osx-cpu-temp" on MacOS X.\ncheck_temp=True\n\n#* Which sensor to use for cpu temperature, use options menu to select from list of available sensors.\ncpu_sensor=Auto\n\n#* Show temperatures for cpu cores also if check_temp is True and sensors has been found\nshow_coretemp=True\n\n#* Which temperature scale to use, available values: "celsius", "fahrenheit", "kelvin" and "rankine"\ntemp_scale="celsius"\n\n#* Show CPU frequency, can cause slowdowns on certain systems with some versions of psutil\nshow_cpu_freq=True\n\n#* Draw a clock at top of screen, formatting according to strftime, empty string to disable.\ndraw_clock="%H:%M"\n\n#* Update main ui in background when menus are showing, set this to false if the menus is flickering too much for comfort.\nbackground_update=True\n\n#* Custom cpu model name, empty string to disable.\ncustom_cpu_name=""\n\n#* Optional filter for shown disks, should be full path of a mountpoint, separate multiple values with a comma ",".\n#* Begin line with "exclude=" to change to exclude filter, otherwise defaults to "most include" filter. Example: disks_filter="exclude=/boot, /home/user"\ndisks_filter="exclude=/boot"\n\n#* Show graphs instead of meters for memory values.\nmem_graphs=True\n\n#* If swap memory should be shown in memory box.\nshow_swap=True\n\n#* Show swap as a disk, ignores show_swap value above, inserts itself after first disk.\nswap_disk=True\n\n#* If mem box should be split to also show disks info.\nshow_disks=True\n\n#* Filter out non physical disks. Set this to False to include network disks, RAM disks and similar.\nonly_physical=True\n\n#* Read disks list from /etc/fstab. This also disables only_physical.\nuse_fstab=True\n\n#* Toggles if io stats should be shown in regular disk usage view\nshow_io_stat=True\n\n#* Toggles io mode for disks, showing only big graphs for disk read/write speeds.\nio_mode=False\n\n#* Set to True to show combined read/write io graphs in io mode.\nio_graph_combined=False\n\n#* Set the top speed for the io graphs in MiB/s (10 by default), use format "device:speed" separate disks with a comma ",".\n#* Example: "/dev/sda:100, /dev/sdb:20"\nio_graph_speeds=""\n\n#* Set fixed values for network graphs, default "10M" = 10 Mibibytes, possible units "K", "M", "G", append with "bit" for bits instead of bytes, i.e "100mbit"\nnet_download="100Mbit"\nnet_upload="100Mbit"\n\n#* Start in network graphs auto rescaling mode, ignores any values set above and rescales down to 10 Kibibytes at the lowest.\nnet_auto=True\n\n#* Sync the scaling for download and upload to whichever currently has the highest scale\nnet_sync=False\n\n#* If the network graphs color gradient should scale to bandwidth usage or auto scale, bandwidth usage is based on "net_download" and "net_upload" values\nnet_color_fixed=False\n\n#* Starts with the Network Interface specified here.\nnet_iface="br0"\n\n#* Show battery stats in top right if battery is present\nshow_battery=True\n\n#* Show init screen at startup, the init screen is purely cosmetical\nshow_init=False\n\n#* Enable check for new version from github.com/aristocratos/bpytop at start.\nupdate_check=True\n\n#* Set loglevel for "~/.config/bpytop/error.log" levels are: "ERROR" "WARNING" "INFO" "DEBUG".\n#* The level set includes all lower levels, i.e. "DEBUG" will show all logging info.\nlog_level=DEBUG\n\n```\n\n#### Command line options:\n\n``` text\nusage: bpytop.py [-h] [-b BOXES] [-lc] [-v] [--debug]\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -b BOXES, --boxes BOXES\n                        which boxes to show at start, example: -b "cpu mem net proc"\n  -lc, --low-color      disable truecolor, converts 24-bit colors to 256-color\n  -v, --version         show version info and exit\n  --debug               start with loglevel set to DEBUG overriding value set in config\n```\n\n## LICENSE\n\n[Apache License 2.0](https://github.com/aristocratos/bpytop/blob/master/LICENSE)\n',
    'author': 'Aristocratos',
    'author_email': 'jakob@qvantnet.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aristocratos/bpytop',
    'py_modules': modules,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
